=======
Credits
=======

Development Lead
----------------

* Lukas Heumos <lukas.heumos@posteo.net>
* Philipp Ehmele <philipp_ehm@protonmail.com>

Contributors
------------

* Edmund Miller <edmund.miller@utdallas.edu>
